==> zcrmsdk-1.0.6-py2.py3-none-any.whl: zcrmsdk/__init__.py <==
'''
Created on Sep 1, 2017

@author: sumanth-3058
'''
try:
    from .RestClient import ZCRMRestClient
    from .Operations import ZCRMAttachment,ZCRMCustomView,ZCRMCustomViewCategory,ZCRMCustomViewCriteria,ZCRMEventParticipant,ZCRMField,ZCRMInventoryLineItem,ZCRMJunctionRecord,ZCRMLayout,ZCRMLeadConvertMapping,ZCRMLeadConvertMappingField,ZCRMLookupField,ZCRMModule,ZCRMModuleRelatedList,ZCRMModuleRelation,ZCRMNote,ZCRMPermission,ZCRMPickListValue,ZCRMPriceBookPricing,ZCRMProfile,ZCRMProfileCategory,ZCRMProfileSection,ZCRMRecord,ZCRMRelatedListProperties,ZCRMRole,ZCRMSection,ZCRMTax,ZCRMTrashRecord,ZCRMUser,ZCRMUserCustomizeInfo,ZCRMUserTheme
    from .Org import ZCRMOrganization
    from .CLException import ZCRMException
    from .Utility import APIConstants
    from .OAuthClient import ZohoOAuth,ZohoOAuthClient,ZohoOAuthTokens
except ImportError:
    from RestClient import ZCRMRestClient
    from Operations import ZCRMAttachment,ZCRMCustomView,ZCRMCustomViewCategory,ZCRMCustomViewCriteria,ZCRMEventParticipant,ZCRMField,ZCRMInventoryLineItem,ZCRMJunctionRecord,ZCRMLayout,ZCRMLeadConvertMapping,ZCRMLeadConvertMappingField,ZCRMLookupField,ZCRMModule,ZCRMModuleRelatedList,ZCRMModuleRelation,ZCRMNote,ZCRMPermission,ZCRMPickListValue,ZCRMPriceBookPricing,ZCRMProfile,ZCRMProfileCategory,ZCRMProfileSection,ZCRMRecord,ZCRMRelatedListProperties,ZCRMRole,ZCRMSection,ZCRMTax,ZCRMTrashRecord,ZCRMUser,ZCRMUserCustomizeInfo,ZCRMUserTheme
    from Org import ZCRMOrganization
    from CLException import ZCRMException
    from Utility import APIConstants
    from OAuthClient import ZohoOAuth,ZohoOAuthClient,ZohoOAuthTokens

==> zcrmsdk-2.0.0-py2.py3-none-any.whl: zcrmsdk/__init__.py <==
'''
Created on Sep 1, 2017

@author: sumanth-3058
'''
try:
    from .RestClient import ZCRMRestClient
    from .Operations import ZCRMAttachment,ZCRMCustomView,ZCRMCustomViewCategory,ZCRMCustomViewCriteria,ZCRMEventParticipant,ZCRMField,ZCRMInventoryLineItem,ZCRMJunctionRecord,ZCRMLayout,ZCRMLeadConvertMapping,ZCRMLeadConvertMappingField,ZCRMLookupField,ZCRMModule,ZCRMModuleRelatedList,ZCRMModuleRelation,ZCRMNote,ZCRMPermission,ZCRMPickListValue,ZCRMPriceBookPricing,ZCRMProfile,ZCRMProfileCategory,ZCRMProfileSection,ZCRMRecord,ZCRMRelatedListProperties,ZCRMRole,ZCRMSection,ZCRMTax,ZCRMTrashRecord,ZCRMUser,ZCRMUserCustomizeInfo,ZCRMUserTheme
    from .Org import ZCRMOrganization
    from .CLException import ZCRMException
    from .Utility import APIConstants
    from .OAuthClient import ZohoOAuth,ZohoOAuthClient,ZohoOAuthTokens,AbstractZohoOAuthPersistence
except ImportError:
    from RestClient import ZCRMRestClient
    from Operations import ZCRMAttachment,ZCRMCustomView,ZCRMCustomViewCategory,ZCRMCustomViewCriteria,ZCRMEventParticipant,ZCRMField,ZCRMInventoryLineItem,ZCRMJunctionRecord,ZCRMLayout,ZCRMLeadConvertMapping,ZCRMLeadConvertMappingField,ZCRMLookupField,ZCRMModule,ZCRMModuleRelatedList,ZCRMModuleRelation,ZCRMNote,ZCRMPermission,ZCRMPickListValue,ZCRMPriceBookPricing,ZCRMProfile,ZCRMProfileCategory,ZCRMProfileSection,ZCRMRecord,ZCRMRelatedListProperties,ZCRMRole,ZCRMSection,ZCRMTax,ZCRMTrashRecord,ZCRMUser,ZCRMUserCustomizeInfo,ZCRMUserTheme
    from Org import ZCRMOrganization
    from CLException import ZCRMException
    from Utility import APIConstants
    from OAuthClient import ZohoOAuth,ZohoOAuthClient,ZohoOAuthTokens,AbstractZohoOAuthPersistence
